@@ -1,13 +1,12 @@
-from sqlglot import exp
-from sqlglot import transforms
+from sqlglot import exp, transforms
 from sqlglot.dialects.dialect import (
     Dialect,
     approx_count_distinct_sql,
     format_time_lambda,
     if_sql,
     no_ilike_sql,
-    no_safe_divide_sql,
     no_recursive_cte_sql,
+    no_safe_divide_sql,
     no_trycast_sql,
     rename_func,
     struct_extract_sql,
@@ -117,13 +116,18 @@ def _unnest_to_explode_sql(self, expression):
     return self.join_sql(expression)
 
 
+def _index_sql(self, expression):
+    this = self.sql(expression, "this")
+    table = self.sql(expression, "table")
+    columns = self.sql(expression, "columns")
+    return f"{this} ON TABLE {table} {columns}"
+
+
 class HiveMap(exp.Map):
     is_var_len_args = True
 
 
 class Hive(Dialect):
-    identifiers = ["`"]
-    escape = "\\"
     alias_post_tablesample = True
 
     time_mapping = {
@@ -156,7 +160,8 @@ class Hive(Dialect):
 
     class Tokenizer(Tokenizer):
         QUOTES = ["'", '"']
-
+        IDENTIFIERS = ["`"]
+        ESCAPE = "\\"
         ENCODE = "utf-8"
 
         NUMERIC_LITERALS = {
@@ -228,6 +233,7 @@ class Hive(Dialect):
         WITH_PROPERTIES = [exp.AnonymousProperty]
 
         TYPE_MAPPING = {
+            **Generator.TYPE_MAPPING,
             exp.DataType.Type.TEXT: "STRING",
         }
 
@@ -247,6 +253,7 @@ class Hive(Dialect):
             exp.DiToDate: lambda self, e: f"TO_DATE(CAST({self.sql(e, 'this')} AS STRING), {Hive.dateint_format})",
             exp.FileFormatProperty: lambda self, e: f"STORED AS {e.text('value').upper()}",
             exp.If: if_sql,
+            exp.Index: _index_sql,
             exp.ILike: no_ilike_sql,
             exp.Join: _unnest_to_explode_sql,
             exp.JSONExtract: rename_func("GET_JSON_OBJECT"),
@@ -289,7 +296,8 @@ class Hive(Dialect):
 
         def datatype_sql(self, expression):
             if (
-                expression.this == exp.DataType.Type.VARCHAR
+                expression.this
+                in (exp.DataType.Type.VARCHAR, exp.DataType.Type.NVARCHAR)
                 and not expression.expressions
             ):
                 expression = exp.DataType.build("text")
