@@ -19,9 +19,10 @@ class Oracle(Dialect):
             exp.DataType.Type.BIGINT: "NUMBER",
             exp.DataType.Type.DECIMAL: "NUMBER",
             exp.DataType.Type.DOUBLE: "DOUBLE PRECISION",
-            exp.DataType.Type.TEXT: "VARCHAR2",
             exp.DataType.Type.VARCHAR: "VARCHAR2",
             exp.DataType.Type.NVARCHAR: "NVARCHAR2",
+            exp.DataType.Type.TEXT: "CLOB",
+            exp.DataType.Type.BINARY: "BLOB",
         }
 
         TRANSFORMS = {
