@@ -1,5 +1,4 @@
-from sqlglot import exp
-from sqlglot import transforms
+from sqlglot import exp, transforms
 from sqlglot.dialects.dialect import (
     Dialect,
     format_time_lambda,
@@ -157,6 +156,7 @@ class Presto(Dialect):
         ]
 
         TYPE_MAPPING = {
+            **Generator.TYPE_MAPPING,
             exp.DataType.Type.INT: "INTEGER",
             exp.DataType.Type.FLOAT: "REAL",
             exp.DataType.Type.BINARY: "VARBINARY",
