@@ -306,21 +306,46 @@ class Generator:
     def columndef_sql(self, expression):
         column = self.sql(expression, "this")
         kind = self.sql(expression, "kind")
-        not_null = " NOT NULL" if expression.args.get("not_null") else ""
-        default = self.sql(expression, "default")
-        default = f" DEFAULT {default}" if default else ""
-        auto_increment = (
-            " " + self.token_sql(TokenType.AUTO_INCREMENT)
-            if expression.args.get("auto_increment")
-            else ""
+        constraints = self.expressions(
+            expression, key="constraints", sep=" ", flat=True
         )
-        collate = self.sql(expression, "collate")
-        collate = f" COLLATE {collate}" if collate else ""
-        comment = self.sql(expression, "comment")
-        comment = f" COMMENT {comment}" if comment else ""
-        primary = " PRIMARY KEY" if expression.args.get("primary") else ""
-        unique = " UNIQUE" if expression.args.get("unique") else ""
-        return f"{column} {kind}{not_null}{default}{collate}{comment}{unique}{primary}{auto_increment}"
+
+        if not constraints:
+            return f"{column} {kind}"
+        return f"{column} {kind} {constraints}"
+
+    def columnconstraint_sql(self, expression):
+        this = self.sql(expression, "this")
+        kind_sql = self.sql(expression, "kind")
+        return f"CONSTRAINT {this} {kind_sql}" if this else kind_sql
+
+    def autoincrementcolumnconstraint_sql(self, _):
+        return self.token_sql(TokenType.AUTO_INCREMENT)
+
+    def checkcolumnconstraint_sql(self, expression):
+        this = self.sql(expression, "this")
+        return f"CHECK ({this})"
+
+    def commentcolumnconstraint_sql(self, expression):
+        comment = self.sql(expression, "this")
+        return f"COMMENT {comment}"
+
+    def collatecolumnconstraint_sql(self, expression):
+        collate = self.sql(expression, "this")
+        return f"COLLATE {collate}"
+
+    def defaultcolumnconstraint_sql(self, expression):
+        default = self.sql(expression, "this")
+        return f"DEFAULT {default}"
+
+    def notnullcolumnconstraint_sql(self, _):
+        return "NOT NULL"
+
+    def primarykeycolumnconstraint_sql(self, _):
+        return "PRIMARY KEY"
+
+    def uniquecolumnconstraint_sql(self, _):
+        return "UNIQUE"
 
     def create_sql(self, expression):
         this = self.sql(expression, "this")
@@ -854,6 +879,10 @@ class Generator:
         expression_sql = self.sql(expression, "expression")
         return f"EXTRACT({this} FROM {expression_sql})"
 
+    def check_sql(self, expression):
+        this = self.sql(expression, key="this")
+        return f"CHECK ({this})"
+
     def foreignkey_sql(self, expression):
         expressions = self.expressions(expression, flat=True)
         reference = self.sql(expression, "reference")
@@ -864,6 +893,10 @@ class Generator:
         update = f" ON UPDATE {update}" if update else ""
         return f"FOREIGN KEY ({expressions}){reference}{delete}{update}"
 
+    def unique_sql(self, expression):
+        columns = self.expressions(expression, key="expressions")
+        return f"UNIQUE ({columns})"
+
     def if_sql(self, expression):
         return self.case_sql(
             exp.Case(ifs=[expression], default=expression.args.get("false"))
